@@ -4,6 +4,7 @@ import xmlrpc.client
 import threading
 import zlib
 from os import sep
+import os
 import gettext
 
 import gi
@@ -29,10 +30,12 @@ SUBTITLES_EXT = [
     "asc",
     "txt",
     "sub",
+    "vtt",
     "srt",
     "smi",
     "ssa",
     "ass",
+    "mpl",
 ]
 
 # Map of the language codes used by opensubtitles.org's API to their
@@ -155,10 +158,11 @@ class SearchThread (threading.Thread):
     """
     This is the thread started when the dialog is searching for subtitles
     """
-    def __init__ (self, model, movie_hash, movie_size):
+    def __init__ (self, model, movie_hash, movie_size, movie_title):
         self._model = model
         self._movie_hash = movie_hash
         self._movie_size = movie_size
+        self._movie_title = movie_title
         self._done = False
         self._results = []
         self._lock = threading.Lock ()
@@ -169,7 +173,8 @@ class SearchThread (threading.Thread):
         self._lock.acquire (True)
         (self._results,
          self._message) = self._model.search_subtitles (self._movie_hash,
-                                                        self._movie_size)
+                                                        self._movie_size,
+                                                        self._movie_title)
         self._done = True
         self._lock.release ()
 
@@ -260,7 +265,7 @@ class OpenSubtitlesModel:
         self._token = None
 
         try:
-            import locale
+            import locale # pylint: disable=import-outside-toplevel
             (language_code, _) = locale.getlocale ()
             self.lang = LANGUAGES[language_code.split ('_')[0]]
         except (ImportError, IndexError, AttributeError, KeyError):
@@ -315,7 +320,7 @@ class OpenSubtitlesModel:
 
         return result
 
-    def search_subtitles (self, movie_hash, movie_size):
+    def search_subtitles (self, movie_hash, movie_size, movie_title):
         self._lock.acquire (True)
 
         message = ''
@@ -336,6 +341,19 @@ class OpenSubtitlesModel:
                 self._lock.release ()
                 return (result['data'], message)
 
+            """Not found by movie_hash and moviebytesize, fallback to title"""
+            searchdata = {'sublanguageid': self.lang,
+                          'query'   : movie_title}
+            try:
+                result = self._server.SearchSubtitles (self._token,
+                                                       [searchdata])
+            except xmlrpc.client.ProtocolError:
+                message = _(u'Could not contact the OpenSubtitles website.')
+
+            if result.get ('data'):
+                self._lock.release ()
+                return (result['data'], message)
+
             message = _(u'No results found.')
         else:
             message = log_in_message
@@ -443,10 +461,8 @@ class OpenSubtitles (GObject.Object, # pylint: disable=R0902
     # UI related code
 
     def _build_dialog (self):
-        builder = Totem.plugin_load_interface ("opensubtitles",
-                                               "opensubtitles.ui", True,
-                                               self._totem.get_main_window (), # pylint: disable=no-member
-                                               None)
+        ui_file_path = os.path.dirname (os.path.abspath (__file__)) + sep + 'opensubtitles.ui'
+        builder = Gtk.Builder.new_from_file (ui_file_path)
 
         # Obtain all the widgets we need to initialize
         combobox = builder.get_object ('language_combobox')
@@ -561,7 +577,7 @@ class OpenSubtitles (GObject.Object, # pylint: disable=R0902
     def _delete_menu (self):
         self._totem.empty_menu_section ("subtitle-download-placeholder") # pylint: disable=no-member
 
-    def _get_results (self, movie_hash, movie_size):
+    def _get_results (self, movie_hash, movie_size, movie_title):
         self._list_store.clear ()
         self._apply_button.set_sensitive (False)
         self._find_button.set_sensitive (False)
@@ -569,7 +585,7 @@ class OpenSubtitles (GObject.Object, # pylint: disable=R0902
         cursor = Gdk.Cursor.new (Gdk.CursorType.WATCH)
         self._dialog.get_window ().set_cursor (cursor)
 
-        thread = SearchThread (self._model, movie_hash, movie_size)
+        thread = SearchThread (self._model, movie_hash, movie_size, movie_title)
         thread.start ()
         GLib.idle_add (self._populate_treeview, thread)
 
@@ -775,5 +791,6 @@ class OpenSubtitles (GObject.Object, # pylint: disable=R0902
         self._find_button.set_sensitive (False)
         self._filename = self._totem.get_current_mrl () # pylint: disable=no-member
         (movie_hash, movie_size) = hash_file (self._filename)
+        movie_title = self._totem.get_title_at_playlist_pos(self._totem.get_playlist_pos())
 
-        self._get_results (movie_hash, movie_size)
+        self._get_results (movie_hash, movie_size, movie_title)
